package fr.iutlan.tutodessin;

import java.util.LinkedList;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.view.View.OnTouchListener;

public class Dessin extends View
implements OnTouchListener
{
	/**
	 * Cette classe représente l'un des cercles dessinés à l'écran
	 */
	class Cercle {
		// variables membre : définition du cercle
		int xc, yc, rayon;
		// couleur du cercle (tirée aléatoirement lors de sa création)
		private Paint paint;

		/**
		 * crée un cercle en x,y, rayon r et d'une couleur aléatoire
		 * @param x
		 * @param y
		 * @param r
		 */
		public Cercle(int x, int y, int r)
		{
			// membres = paramètres
			xc = x;
			yc = y;
			rayon = r;

			// création de la peinture (décommenter pour des effets différents)
			paint = new Paint();
			//paint.setDither(true);
			//paint.setAntiAlias(true);
			paint.setColor(Color.rgb((int)(Math.random()*256),(int)(Math.random()*256),(int)(Math.random()*256)));
			//paint.setStyle(Paint.Style.STROKE);
			//paint.setStrokeJoin(Paint.Join.ROUND);
			//paint.setStrokeCap(Paint.Cap.ROUND);
			//paint.setStrokeWidth(8);
		}

		/**
		 * Cette méthode dessine ce cercle sur le canvas
		 * @param canvas
		 */
		public void draw(Canvas canvas)
		{
			canvas.drawCircle(xc, yc, rayon, paint);
		}
	}

	// représente l'ensemble des cercles créés à la main
	LinkedList<Cercle> cercles;

	// constructeur : initialise la liste et installe l'écran
	public Dessin(Context context, AttributeSet attrs)
	{
		super(context, attrs);

		// ne pas oublier d'initialiser la liste à vide
		cercles = new LinkedList<Cercle>();

		// tous les touchers écran seront gérés par cette vue perso
		setOnTouchListener(this);
	}

	@Override
	public void onDraw(Canvas canvas)
	{
		// pour un premier essai
		//Paint paint = new Paint();
		//paint.setColor(Color.BLUE);
		//canvas.drawCircle(100, 100, 50, paint);

		// dessiner tous les cercles de la liste
		for (Cercle cercle: cercles)
			cercle.draw(canvas);
	}


	/**
	 * appelée quand l'utilisateur touche l'écran
	 */
	@Override
	public boolean onTouch(View v, MotionEvent event)
	{
		// coordonnées actuelles du touché
		int x = (int)event.getX();
		int y = (int)event.getY();

		switch (event.getAction()) {

		case MotionEvent.ACTION_DOWN:
			// premier touché d'un déplacement du doigt sur la dalle : on recrée le cercle
			cercles.add(new Cercle(x, y, 1));
			break;

		case MotionEvent.ACTION_MOVE:
			// dernière position d'un glissé : on change le rayon du dernier cercle créé
			Cercle cercle = cercles.getLast();
			// le rayon = distance entre le toucher actuel et le centre du cercle
			cercle.rayon = (int)Math.sqrt( (x-cercle.xc)*(x-cercle.xc) + (y-cercle.yc)*(y-cercle.yc) );
			break;
		}

		// demander de redessiner la vue => appel à onDraw
		this.invalidate();

		return true;
	}

}
